@@ -23,6 +23,7 @@
 
 // Konsole
 #include "ui_HistorySizeDialog.h"
+#include "Shortcut_p.h"
 
 #include <KLocalizedString>
 #include <QDialogButtonBox>
@@ -42,7 +43,7 @@ HistorySizeDialog::HistorySizeDialog(QWidget* parent)
     mainLayout->addWidget(mainWidget);
     QPushButton *okButton = buttonBox->button(QDialogButtonBox::Ok);
     okButton->setDefault(true);
-    okButton->setShortcut(Qt::CTRL | Qt::Key_Return);
+    okButton->setShortcut(Konsole::ACCEL | Qt::Key_Return);
     connect(buttonBox, &QDialogButtonBox::accepted, this, &HistorySizeDialog::accept);
     connect(buttonBox, &QDialogButtonBox::rejected, this, &HistorySizeDialog::reject);
     mainLayout->addWidget(buttonBox);
