@@ -32,6 +32,7 @@
 #include <KColorScheme>
 #include <QLineEdit>
 #include <KLocalizedString>
+#include "KonsoleSettings.h"
 
 using namespace Konsole;
 
@@ -128,15 +129,14 @@ IncrementalSearchBar::IncrementalSearchBar(QWidget* aParent)
     _highlightMatches = optionsMenu->addAction(i18nc("@item:inmenu", "Highlight all matches"));
     _highlightMatches->setCheckable(true);
     _highlightMatches->setToolTip(i18nc("@info:tooltip", "Sets whether matching text should be highlighted"));
-    _highlightMatches->setChecked(true);
     connect(_highlightMatches, &QAction::toggled, this, &Konsole::IncrementalSearchBar::highlightMatchesToggled);
 
     _reverseSearch = optionsMenu->addAction(i18n("Search backwards"));
     _reverseSearch->setCheckable(true);
     _reverseSearch->setToolTip(i18n("Sets whether search should start from the bottom"));
-    _reverseSearch->setChecked(true);
     connect(_reverseSearch, &QAction::toggled, this, &Konsole::IncrementalSearchBar::updateButtonsAccordingToReverseSearchSetting);
     updateButtonsAccordingToReverseSearchSetting();
+    setOptions();
 
     barLayout->addStretch();
 
@@ -277,3 +277,26 @@ const QBitArray IncrementalSearchBar::optionsChecked()
     return options;
 }
 
+void IncrementalSearchBar::setOptions()
+{
+    if (KonsoleSettings::searchCaseSensitive()) {
+        _caseSensitive->setChecked(true);
+    } else {
+        _caseSensitive->setChecked(false);
+    }
+    if (KonsoleSettings::searchRegExpression()) {
+        _regExpression->setChecked(true);
+    } else {
+        _regExpression->setChecked(false);
+    }
+    if (KonsoleSettings::searchHighlightMatches()) {
+        _highlightMatches->setChecked(true);
+    } else {
+        _highlightMatches->setChecked(false);
+    }
+    if (KonsoleSettings::searchReverseSearch()) {
+        _reverseSearch->setChecked(true);
+    } else {
+        _reverseSearch->setChecked(false);
+    }
+}
