@@ -51,6 +51,9 @@ public:
     KeyboardTranslatorManager();
     ~KeyboardTranslatorManager();
 
+    KeyboardTranslatorManager(const KeyboardTranslatorManager&) = delete;
+    KeyboardTranslatorManager& operator=(const KeyboardTranslatorManager&) = delete;
+
     /**
      * Adds a new translator.  If a translator with the same name
      * already exists, it will be replaced by the new translator.
