@@ -141,6 +141,11 @@ public:
      */
     void closePty();
 
+    /**
+     * Sends EOF to the controlled process, this is the preferred method of telling e. g. bash to close
+     */
+    void sendEof();
+
 public slots:
     /**
      * Put the pty into UTF-8 mode on systems which support it.
@@ -151,7 +156,7 @@ public slots:
      * Sends data to the process currently controlling the
      * teletype ( whose id is returned by foregroundProcessGroup() )
      *
-     * @param buffer the data to send.
+     * @param data the data to send.
      */
     void sendData(const QByteArray& data);
 
